==> s-postgray-0.8.1.tar.gz: s-postgray-0.8.1/include/su/re.h <==
/*@ (POSIX) Regular expressions.
 *
 * Copyright (c) 2021 - 2023 Steffen Nurpmeso <steffen@sdaoden.eu>.
 * SPDX-License-Identifier: ISC
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef su_RE_H
#define su_RE_H
#include <su/code.h>
#ifdef su_HAVE_RE
#define su_HEADER
#include <su/code-in.h>
C_DECL_BEGIN
struct su_re;
struct su_re_match;
/* re {{{ */
enum su_re_setup_flags{
	su_RE_SETUP_NONE = 0,
	su_RE_SETUP_EXT = 1u<<0,
	su_RE_SETUP_EXTENDED = su_RE_SETUP_EXT,
	su_RE_SETUP_ICASE = 1u<<1,
	su_RE_SETUP_NONL = 1u<<2,
	su_RE_SETUP_TEST_ONLY = 1u<<3
};
enum su_re_eval_flags{
	su_RE_EVAL_NONE = 0,
	su_RE_EVAL_NOTBOL = 1u<<0,
	su_RE_EVAL_NOTEOL = 1u<<1
};
enum su_re_errors{
	su_RE_ERROR_NONE = 0,
	su_RE_ERROR_BADBR,
	su_RE_ERROR_BADPAT,
	su_RE_ERROR_BADRPT,
	su_RE_ERROR_BRACE,
	su_RE_ERROR_BRACK,
	su_RE_ERROR_COLLATE,
	su_RE_ERROR_CTYPE,
	su_RE_ERROR_ESCAPE,
	su_RE_ERROR_PAREN,
	su_RE_ERROR_RANGE,
	su_RE_ERROR_SPACE,
	su_RE_ERROR_SUBREG,
	su_RE_ERROR_MISC
};
struct su_re{
	BITENUM_IS(u8,su_re_setup_flags) re_setup_flags;
	BITENUM_IS(u8,su_re_errors) re_error; /* (to make it fit in 8-bit) */
	boole re_eval_ok;
	BITENUM_IS(u8,su_re_eval_flags) re_eval_flags;
	u32 re_group_count;
	struct su_re_match *re_match;
	char const *re_input;
	void *re_super;
};
struct su_re_match{
	s64 rem_start;
	s64 rem_end;
};
EXPORT struct su_re *su__re_reset(struct su_re *self);
EXPORT char const *su__re_error_doc(u8 error);
INLINE struct su_re *su_re_create(struct su_re *self){
	ASSERT(self);
	self->re_error = su_RE_ERROR_NONE;
	self->re_super = NIL;
	return self;
}
INLINE void su_re_gut(struct su_re *self){
	ASSERT(self);
	if(self->re_super != NIL)
		su__re_reset(self);
}
INLINE struct su_re *su_re_reset(struct su_re *self){
	ASSERT(self);
	if(self->re_super != NIL)
		self = su__re_reset(self);
	return self;
}
EXPORT BITENUM_IS(u8,su_re_errors) su_re_setup_cp(struct su_re *self,
		char const *expr, BITENUM_IS(u8,su_re_setup_flags) flags);
INLINE boole su_re_is_setup(struct su_re const *self){
	ASSERT(self);
	return (self->re_super != NIL);
}
INLINE char const *su_re_error_doc(struct su_re const *self){
	ASSERT(self);
	return su__re_error_doc(self->re_error);
}
EXPORT boole su_re_eval_cp(struct su_re *self, char const *input, BITENUM_IS(u8,su_re_eval_flags) flags);
INLINE char const *su_re_get_error_doc(enum su_re_errors error) {return su__re_error_doc(S(u8,error));}
/* }}} */
C_DECL_END
#include <su/code-ou.h>
#endif /* su_HAVE_RE */
#endif /* !su_RE_H */
/* s-itt-mode */

==> s-postgray-0.8.3.tar.gz: s-postgray-0.8.3/include/su/re.h <==
/*@ (POSIX) Regular expressions.
 *
 * Copyright (c) 2021 - 2024 Steffen Nurpmeso <steffen@sdaoden.eu>.
 * SPDX-License-Identifier: ISC
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef su_RE_H
#define su_RE_H
#include <su/code.h>
#ifdef su_HAVE_RE
#define su_HEADER
#include <su/code-in.h>
C_DECL_BEGIN
struct su_re;
struct su_re_match;
/* re {{{ */
enum su_re_setup_flags{
	su_RE_SETUP_NONE = 0,
	su_RE_SETUP_EXT = 1u<<0,
	su_RE_SETUP_EXTENDED = su_RE_SETUP_EXT,
	su_RE_SETUP_ICASE = 1u<<1,
	su_RE_SETUP_NONL = 1u<<2,
	su_RE_SETUP_TEST_ONLY = 1u<<3
};
enum su_re_eval_flags{
	su_RE_EVAL_NONE = 0,
	su_RE_EVAL_NOTBOL = 1u<<0,
	su_RE_EVAL_NOTEOL = 1u<<1
};
enum su_re_errors{
	su_RE_ERROR_NONE = 0,
	su_RE_ERROR_BADBR,
	su_RE_ERROR_BADPAT,
	su_RE_ERROR_BADRPT,
	su_RE_ERROR_BRACE,
	su_RE_ERROR_BRACK,
	su_RE_ERROR_COLLATE,
	su_RE_ERROR_CTYPE,
	su_RE_ERROR_ESCAPE,
	su_RE_ERROR_PAREN,
	su_RE_ERROR_RANGE,
	su_RE_ERROR_SPACE,
	su_RE_ERROR_SUBREG,
	su_RE_ERROR_MISC
};
struct su_re{
	BITENUM(u8,su_re_setup_flags) re_setup_flags;
	BITENUM(u8,su_re_errors) re_error; /* (to make it fit in 8-bit) */
	boole re_eval_ok;
	BITENUM(u8,su_re_eval_flags) re_eval_flags;
	u32 re_group_count;
	struct su_re_match *re_match;
	char const *re_input;
	void *re_super;
};
struct su_re_match{
	s64 rem_start;
	s64 rem_end;
};
EXPORT struct su_re *su__re_reset(struct su_re *self);
EXPORT char const *su__re_error_doc(u8 error);
INLINE struct su_re *su_re_create(struct su_re *self){
	ASSERT(self);
	self->re_error = su_RE_ERROR_NONE;
	self->re_super = NIL;
	return self;
}
INLINE void su_re_gut(struct su_re *self){
	ASSERT(self);
	if(self->re_super != NIL)
		su__re_reset(self);
}
INLINE struct su_re *su_re_reset(struct su_re *self){
	ASSERT(self);
	if(self->re_super != NIL)
		self = su__re_reset(self);
	return self;
}
EXPORT BITENUM(u8,su_re_errors) su_re_setup_cp(struct su_re *self,
		char const *expr, BITENUM(u8,su_re_setup_flags) flags);
INLINE boole su_re_is_setup(struct su_re const *self){
	ASSERT(self);
	return (self->re_super != NIL);
}
INLINE char const *su_re_error_doc(struct su_re const *self){
	ASSERT(self);
	return su__re_error_doc(self->re_error);
}
EXPORT boole su_re_eval_cp(struct su_re *self, char const *input, BITENUM(u8,su_re_eval_flags) flags);
INLINE char const *su_re_get_error_doc(enum su_re_errors error) {return su__re_error_doc(S(u8,error));}
/* }}} */
C_DECL_END
#include <su/code-ou.h>
#endif /* su_HAVE_RE */
#endif /* !su_RE_H */
/* s-itt-mode */
